import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/curran/0ac4077c7fc6390f5dd33bf5c06cb5ff/raw/605c54080c7a93a417a3cea93fd52e7550e76500/UN_Population_2019.csv';

const width = 960;
const height = 500;

const App = () => {
  const [data, setData] = useState(null);
  useEffect(() => {
    const row = d => {
  		d.Population = +(d['2020'])
    	return d;
  	};
    csv(csvUrl, row).then(data => {
    	setData(data.slice(0, 10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  
  console.log(data[0]);
  
  const yScale = scaleBand()
  	.domain(data.map(d => d.Country))
  	.range([0, height]);
  
  const xScale = scaleLinear()
  	.domain([0, max(data, d => d.Population)])
		.range([0, width]);
  
  return (
    <svg width={width} height={height}>
      {data.map(d => ( <rect x={0} y={yScale(d.Country)} width={xScale(d.Population)} height={yScale.bandwidth()}/>))}
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

// To compute the arcs manually (without d3.pie):
// data.map((d, i) => (
//   <path
//     fill={d['RGB hex value']}
//     d={pieArc({
//       startAngle: (i / data.length) * 2 * Math.PI,
//       endAngle: ((i + 1) / data.length) * 2 * Math.PI
//     })}
//   />
// ))
